<!--
This file is part of pybhspc
Copyright 2024 Board of Regents of the University of Wisconsin System
SPDX-License-Identifier: MIT
-->

# The `bh_spc.spcm` module

::: bh_spc.spcm
    options:
      heading_level: 2
